@@ -1,5 +1,5 @@
 `RM` <-
-function(X, W, se = TRUE, sum0 = TRUE)
+function(X, W, se = TRUE, sum0 = TRUE, etaStart)
 {
 #...X: 0/1 person*item matrix
 
@@ -11,10 +11,13 @@ model <- "RM"
 if (missing(W)) W <- NA
 else W <- as.matrix(W)
 
+if (missing(etaStart)) etaStart <- NA
+else etaStart <- as.vector(etaStart)
+
 XWcheck <- datcheck(X,W,mpoints,groupvec,model)                              #inital check of X and W
 X <- XWcheck$X
 
-lres <- likLR(X,W,mpoints,groupvec,model,st.err=se,sum0)
+lres <- likLR(X,W,mpoints,groupvec,model,st.err=se,sum0,etaStart)
 parest <- lres$parest                             #full groups for parameter estimation
                                 
 loglik <- -parest$minimum                         #log-likelihood value
