@@ -10,13 +10,12 @@ summary.LR <- function(object,...)
   cat("\n")
   
   mt_vek <- apply(object$X,2,max,na.rm=TRUE) 
-  if (object$model=="RM") {                                   #Rasch model
-    betanames <- paste("beta",colnames(object$X)) }
-  if ((object$model=="RSM") || (object$model=="PCM")) {       #PCM and RSM
-    catnames <- sequence(mt_vek)
-    itnames <- rep(colnames(object$X),mt_vek)
-    betanames <- paste("beta",paste(itnames,catnames,sep="."))
-  }
+  #if ((object$model=="RSM") || (object$model=="PCM")) {       #PCM and RSM
+  #  catnames <- sequence(mt_vek)
+  #  itnames <- rep(colnames(object$X),mt_vek)
+  #  betanames <- paste("beta",paste(itnames,catnames,sep="."))
+  #}
+  
   
   for (i in 1:length(object$betalist)) {
     cat("\n")
@@ -25,9 +24,8 @@ summary.LR <- function(object,...)
     cat("Log-likelihood: ",object$likgroup[i])
     cat("\n\n")
     cat("Beta Parameters: \n")
-    betavec <- t(as.matrix(object$betalist[[i]]))
-    colnames(betavec) <- "Estimate"
-    rownames(betavec) <- betanames
+    betavec <- object$betalist[[i]]
+    #if (is.null(names(betavec))) names(betavec) <- betanames
     print(betavec)
     cat("\n")
   }
